[pytango] 104/483: c

Sandor Bodo-Merle sbodomerle-guest at moszumanska.debian.org
Thu Sep 28 19:14:29 UTC 2017


This is an automated email from the git hooks/post-receive script.

sbodomerle-guest pushed a commit to annotated tag bliss_8.10
in repository pytango.

commit b92b676c77bfa967972abcff4c09bb9bd7fafda5
Author: tiagocoutinho <tiagocoutinho at 4e9c00fd-8f2e-0410-aa12-93ce3db5e235>
Date:   Thu Mar 1 10:38:28 2012 +0000

    c
    
    git-svn-id: http://svn.code.sf.net/p/tango-cs/code/bindings/PyTango/trunk@19527 4e9c00fd-8f2e-0410-aa12-93ce3db5e235
---
 doc/conf.py                                        |   6 +-
 doc/index.rst                                      |  14 +-
 doc/{spock => itango}/features.rst                 |   6 +-
 doc/{spock => itango}/highlights.rst               | 210 +++++++++----------
 doc/itango/index.rst                               |  37 ++++
 doc/{spock/spock00.png => itango/itango00.png}     | Bin
 doc/{spock/spock01.png => itango/itango01.png}     | Bin
 doc/{spock/spock02.png => itango/itango02.png}     | Bin
 doc/{spock/spock03.png => itango/itango03.png}     | Bin
 doc/{spock/spock04.png => itango/itango04.png}     | Bin
 doc/quicktour.rst                                  | 223 +++++++++++----------
 doc/quicktour_old.rst                              |   2 +-
 ...ghlighting.py => tango_console_highlighting.py} |  30 +--
 doc/spock/index.rst                                |  46 -----
 doc/start.rst                                      |  28 +--
 15 files changed, 300 insertions(+), 302 deletions(-)

diff --git a/doc/conf.py b/doc/conf.py
index 2986ae0..69f2a65 100644
--- a/doc/conf.py
+++ b/doc/conf.py
@@ -52,7 +52,7 @@ extensions = ['sphinx.ext.pngmath',
               'sphinx.ext.graphviz',
               'sphinx.ext.intersphinx',
               'ipython_console_highlighting',
-              'spock_console_highlighting']
+              'tango_console_highlighting']
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -68,7 +68,7 @@ master_doc = 'index'
 
 # General information about the project.
 project = u'PyTango'
-copyright = u'2010, ALBA - CELLS'
+copyright = u'2012, ALBA - CELLS'
 copyright = u"""Except where otherwise noted, content on this site is
 licensed under a Creative Commons Attribution 3.0 License"""
 
@@ -117,7 +117,7 @@ exclude_trees = ['_build']
 
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
-pygments_style = 'spock_console_highlighting.SpockStyle'
+pygments_style = 'tango_console_highlighting.TangoStyle'
 
 # A list of ignored prefixes for module index sorting.
 #modindex_common_prefix = []
diff --git a/doc/index.rst b/doc/index.rst
index 0566c6d..e31e23e 100644
--- a/doc/index.rst
+++ b/doc/index.rst
@@ -9,19 +9,19 @@
 Welcome to PyTango |version| documentation!
 ===========================================
 
-|PyTangoLogoMedium| |spocklogo|
+|PyTangoLogoMedium| |itangologo|
 
 .. sidebar:: Latest news:
-    
+
+    2012-03-01:
+        PyTango 7.2.3 is out!
+            
     2011-12-12:
         PyTango 7.2.2 is out!
 
     2011-04-15:
         PyTango 7.2.0 is out!
 
-    2011-04-14:
-        PyTango 7.1.6 is out!
-
 
 PyTango is a python module that exposes to Python_ the complete Tango_ C++ API.
 This includes both client and server API.
@@ -49,9 +49,9 @@ Tango_ homepage where you will find plenty of documentation, faq and tutorials.
     :align: middle
     :alt: PyTango logo
     
-.. |spocklogo| image:: spock/spock03.png
+.. |itangologo| image:: itango/spock03.png
     :align: middle
-    :alt: Spock console
+    :alt: ITango console
 
 .. _Python: http://www.python.org/
 .. _IPython: http://ipython.scipy.org/
diff --git a/doc/spock/features.rst b/doc/itango/features.rst
similarity index 84%
rename from doc/spock/features.rst
rename to doc/itango/features.rst
index d7b54c1..f1e14be 100644
--- a/doc/spock/features.rst
+++ b/doc/itango/features.rst
@@ -1,10 +1,10 @@
 
-.. _spock-features:
+.. _itango-features:
 
 Features
 ========
 
-Spock works like a normal python console, but it gives you in addition a nice
+ITango works like a normal python console, but it gives you in addition a nice
 set of features from IPython_ like:
 
     - proper (bash-like) command completion
@@ -34,7 +34,7 @@ Plus an additional set o Tango_ specific features:
     - store favorite tango devices
     - tango color modes
 
-Check the :ref:`spock-highlights` to see how to put these feature to good use :-)
+Check the :ref:`itango-highlights` to see how to put these feature to good use :-)
 
 .. _IPython: http://ipython.scipy.org/
 .. _Tango: http://www.tango-controls.org/
\ No newline at end of file
diff --git a/doc/spock/highlights.rst b/doc/itango/highlights.rst
similarity index 76%
rename from doc/spock/highlights.rst
rename to doc/itango/highlights.rst
index 7371d90..03888e2 100644
--- a/doc/spock/highlights.rst
+++ b/doc/itango/highlights.rst
@@ -1,7 +1,7 @@
 
 .. currentmodule:: PyTango
 
-.. _spock-highlights:
+.. _itango-highlights:
 
 Highlights
 ==========
@@ -9,74 +9,74 @@ Highlights
 Tab completion
 --------------
 
-Spock exports many tango specific objects to the console namespace.
+ITango exports many tango specific objects to the console namespace.
 These include:
 
     - the PyTango module itself
       
-      .. sourcecode:: spock
+      .. sourcecode:: itango
 
-            Spock <homer:10000> [1]: PyTango
+            ITango <homer:10000> [1]: PyTango
                          Result [1]: <module 'PyTango' from ...>
                          
     - The :class:`DeviceProxy` (=Device), :class:`AttributeProxy` (=Attribute),
       :class:`Database` and :class:`Group` classes
       
-      .. sourcecode:: spock
+      .. sourcecode:: itango
 
-            Spock <homer:10000> [1]: De<tab>
+            ITango <homer:10000> [1]: De<tab>
             DeprecationWarning            Device       DeviceProxy
 
-            Spock <homer:10000> [2]: Device
+            ITango <homer:10000> [2]: Device
                          Result [2]: <class 'PyTango._PyTango.DeviceProxy'>
             
-            Spock <homer:10000> [3]: Device("sys/tg_test/1")
+            ITango <homer:10000> [3]: Device("sys/tg_test/1")
                          Result [3]: DeviceProxy(sys/tg_test/1)
                          
-            Spock <homer:10000> [4]: Datab<tab>
+            ITango <homer:10000> [4]: Datab<tab>
             
-            Spock <homer:10000> [4]: Database
+            ITango <homer:10000> [4]: Database
             
-            Spock <homer:10000> [4]: Att<tab>
+            ITango <homer:10000> [4]: Att<tab>
             Attribute       AttributeError  AttributeProxy
             
-    - The tango :class:`PyTango.Database` object to which the spock session is 
+    - The tango :class:`PyTango.Database` object to which the itango session is 
       currently connected
       
-      .. sourcecode:: spock
+      .. sourcecode:: itango
 
-            Spock <homer:10000> [1]: db
+            ITango <homer:10000> [1]: db
                          Result [1]: Database(homer, 10000)
     
 Device name completion
 ----------------------
 
-Spock knows the complete list of device names (including alias) for the current
+ITango knows the complete list of device names (including alias) for the current
 tango database. This means that when you try to create a new Device, by pressing
 <tab> you can see a context sensitive list of devices.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: test = Device("<tab>
+    ITango <homer:10000> [1]: test = Device("<tab>
     Display all 3654 possibilities? (y or n) n
     
-    Spock <homer:10000> [1]: test = Device("sys<tab>
+    ITango <homer:10000> [1]: test = Device("sys<tab>
     sys/access_control/1  sys/database/2        sys/tautest/1         sys/tg_test/1
     
-    Spock <homer:10000> [2]: test = Device("sys/tg_test/1")
+    ITango <homer:10000> [2]: test = Device("sys/tg_test/1")
 
 Attribute name completion
 -------------------------
 
-Spock can inspect the list of attributes in case the device server for the device
+ITango can inspect the list of attributes in case the device server for the device
 where the attribute resides is running.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: short_scalar = Attribute("sys<tab>
+    ITango <homer:10000> [1]: short_scalar = Attribute("sys<tab>
     sys/access_control/1/  sys/database/2/        sys/tautest/1/         sys/tg_test/1/
     
-    Spock <homer:10000> [1]: short_scalar = Attribute("sys/tg_test/1/<tab>
+    ITango <homer:10000> [1]: short_scalar = Attribute("sys/tg_test/1/<tab>
     sys/tg_test/1/State                sys/tg_test/1/no_value
     sys/tg_test/1/Status               sys/tg_test/1/short_image
     sys/tg_test/1/ampli                sys/tg_test/1/short_image_ro
@@ -90,9 +90,9 @@ where the attribute resides is running.
     sys/tg_test/1/double_scalar        sys/tg_test/1/string_image_ro
     ...
 
-    Spock <homer:10000> [1]: short_scalar = Attribute("sys/tg_test/1/short_scalar")
+    ITango <homer:10000> [1]: short_scalar = Attribute("sys/tg_test/1/short_scalar")
     
-    Spock <homer:10000> [29]: print test.read()
+    ITango <homer:10000> [29]: print test.read()
     DeviceAttribute[
     data_format = PyTango._PyTango.AttrDataFormat.SCALAR
       dim_x = 1
@@ -115,15 +115,15 @@ where the attribute resides is running.
 Automatic tango object member completion
 ----------------------------------------
 
-When you create a new tango object, (ex.: a device), spock is able to find out
+When you create a new tango object, (ex.: a device), itango is able to find out
 dynamically which are the members of this device (including tango commands 
 and attributes if the device is currently running)
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: test = Device("sys/tg_test/1")
+    ITango <homer:10000> [1]: test = Device("sys/tg_test/1")
     
-    Spock <homer:10000> [2]: test.<tab>
+    ITango <homer:10000> [2]: test.<tab>
     Display all 240 possibilities? (y or n)
     ...
     test.DevVoid                            test.get_access_control
@@ -133,14 +133,14 @@ and attributes if the device is currently running)
     test.SwitchStates                       test.get_attribute_list
     ...
     
-    Spock <homer:10000> [2]: test.short_<tab>
+    ITango <homer:10000> [2]: test.short_<tab>
     test.short_image        test.short_scalar       test.short_scalar_rww   test.short_spectrum
     test.short_image_ro     test.short_scalar_ro    test.short_scalar_w     test.short_spectrum_ro
 
-    Spock <homer:10000> [2]: test.short_scalar        # old style: test.read_attribute("short_scalar").value
+    ITango <homer:10000> [2]: test.short_scalar        # old style: test.read_attribute("short_scalar").value
                  Result [2]: 252
 
-    Spock <homer:10000> [3]: test.Dev<tab>
+    ITango <homer:10000> [3]: test.Dev<tab>
     test.DevBoolean               test.DevUShort                test.DevVarShortArray
     test.DevDouble                test.DevVarCharArray          test.DevVarStringArray
     test.DevFloat                 test.DevVarDoubleArray        test.DevVarULongArray
@@ -149,28 +149,28 @@ and attributes if the device is currently running)
     test.DevString                test.DevVarLongArray          
     test.DevULong                 test.DevVarLongStringArray
     
-    Spock <homer:10000> [3]: test.DevDouble(56.433)  # old style: test.command_inout("DevDouble").
+    ITango <homer:10000> [3]: test.DevDouble(56.433)  # old style: test.command_inout("DevDouble").
                  Result [3]: 56.433
 
 Tango classes as :class:`DeviceProxy`
 ---------------------------------------------
 
-Spock exports all known tango classes as python alias to :class:`DeviceProxy`. 
+ITango exports all known tango classes as python alias to :class:`DeviceProxy`. 
 This way, if you want to create a device of class which you already know 
 (say, Libera, for example) you can do:
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: lib01 = Libera("BO01/DI/BPM-01")
+    ITango <homer:10000> [1]: lib01 = Libera("BO01/DI/BPM-01")
 
 One great advantage is that the tango device name completion is sensitive to the
 type of device you want to create. This means that if you are in the middle of
 writting a device name and you press the <tab> key, only devices of the tango
 class 'Libera' will show up as possible completions.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: bpm1 = Libera("<tab>
+    ITango <homer:10000> [1]: bpm1 = Libera("<tab>
     BO01/DI/BPM-01  BO01/DI/BPM-09  BO02/DI/BPM-06  BO03/DI/BPM-03  BO03/DI/BPM-11  BO04/DI/BPM-08
     BO01/DI/BPM-02  BO01/DI/BPM-10  BO02/DI/BPM-07  BO03/DI/BPM-04  BO04/DI/BPM-01  BO04/DI/BPM-09
     BO01/DI/BPM-03  BO01/DI/BPM-11  BO02/DI/BPM-08  BO03/DI/BPM-05  BO04/DI/BPM-02  BO04/DI/BPM-10
@@ -180,23 +180,23 @@ class 'Libera' will show up as possible completions.
     BO01/DI/BPM-07  BO02/DI/BPM-04  BO03/DI/BPM-01  BO03/DI/BPM-09  BO04/DI/BPM-06  
     BO01/DI/BPM-08  BO02/DI/BPM-05  BO03/DI/BPM-02  BO03/DI/BPM-10  BO04/DI/BPM-07
 
-    Spock <homer:10000> [1]: bpm1 = Libera("BO01<tab>
+    ITango <homer:10000> [1]: bpm1 = Libera("BO01<tab>
     BO01/DI/BPM-01  BO01/DI/BPM-03  BO01/DI/BPM-05  BO01/DI/BPM-07  BO01/DI/BPM-09  BO01/DI/BPM-11
     BO01/DI/BPM-02  BO01/DI/BPM-04  BO01/DI/BPM-06  BO01/DI/BPM-08  BO01/DI/BPM-10
     
-    Spock <homer:10000> [1]: bpm1 = Libera("BO01/DI/BPM-
+    ITango <homer:10000> [1]: bpm1 = Libera("BO01/DI/BPM-
     
     
 List tango devices, classes, servers
-------------------------------------
+--------------------------------------
 
-Spock provides a set of magic functions (ipython lingo) that allow you to check
+ITango provides a set of magic functions (ipython lingo) that allow you to check
 for the list tango devices, classes and servers which are registered in the 
 current database.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: lsdev
+    ITango <homer:10000> [1]: lsdev
                                       Device                     Alias                    Server                Class
     ---------------------------------------- ------------------------- ------------------------- --------------------
                   expchan/BL99_Dummy0DCtrl/1                  BL99_0D1                 Pool/BL99      ZeroDExpChannel
@@ -219,7 +219,7 @@ current database.
                  expchan/BL99_UxTimerCtrl1/1                BL99_Timer                 Pool/BL99         CTExpChannel
     ...
     
-    Spock <homer:10000> [1]: lsdevclass
+    ITango <homer:10000> [1]: lsdevclass
     SimuCoTiCtrl                   TangoAccessControl             ZeroDExpChannel
     Door                           Motor                          DataBase
     MotorGroup                     IORegister                     SimuMotorCtrl
@@ -227,7 +227,7 @@ current database.
     SimuMotor                      SimuCounterEx                  MeasurementGroup
     Pool                           CTExpChannel
 
-    Spock <homer:10000> [1]: lsserv
+    ITango <homer:10000> [1]: lsserv
     MacroServer/BL99               MacroServer/BL98               Pool/V2
     Pool/BL99                      Pool/BL98                      TangoTest/test
     Pool/tcoutinho                 Simulator/BL98
@@ -235,23 +235,23 @@ current database.
     MacroServer/tcoutinho          Simulator/BL99
 
 Customized tango error message and introspection
-------------------------------------------------
+----------------------------------------------------
 
-Spock intercepts tango exceptions that occur when you do tango operations 
+ITango intercepts tango exceptions that occur when you do tango operations 
 (ex.: write an attribute with a value outside the allowed limits) and tries to
 display it in a summarized, user friendly way.
 If you need more detailed information about the last tango error, you can use
 the magic command 'tango_error'.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: test = Device("sys/tg_test/1")
+    ITango <homer:10000> [1]: test = Device("sys/tg_test/1")
 
-    Spock <homer:10000> [2]: test.no_value
+    ITango <homer:10000> [2]: test.no_value
     API_AttrValueNotSet : Read value for attribute no_value has not been updated
     For more detailed information type: tango_error
 
-    Spock <homer:10000> [3]: tango_error
+    ITango <homer:10000> [3]: tango_error
     Last tango error:
     DevFailed[
     DevError[
@@ -266,14 +266,14 @@ the magic command 'tango_error'.
     severity = PyTango._PyTango.ErrSeverity.ERR]]
 
 Switching database
-------------------
+---------------------
 
 You can switch database simply by executing the 'switchdb <host> [<port>]' magic
 command.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: switchdb
+    ITango <homer:10000> [1]: switchdb
 
     Must give new database name in format <host>[:<port>].
     <port> is optional. If not given it defaults to 10000.
@@ -283,75 +283,75 @@ command.
     switchdb homer 10005
     switchdb homer
     
-    Spock <homer:10000> [2]: switchdb bart       # by default port is 10000
+    ITango <homer:10000> [2]: switchdb bart       # by default port is 10000
     
-    Spock <bart:10000> [3]: switchdb lisa 10005  # you can use spaces between host and port
+    ITango <bart:10000> [3]: switchdb lisa 10005  # you can use spaces between host and port
     
-    Spock <lisa:10005> [4]: switchdb marge:10005 # or the traditional ':'
+    ITango <lisa:10005> [4]: switchdb marge:10005 # or the traditional ':'
 
 Refreshing the database
------------------------
+--------------------------
 
-When spock starts up or when the database is switched, a query is made to the
+When itango starts up or when the database is switched, a query is made to the
 tango Database device server which provides all necessary data. This
-data is stored locally in a spock cache which is used to provide all the nice 
+data is stored locally in a itango cache which is used to provide all the nice 
 features.
 If the Database server is changed in some way (ex: a new device server is registered),
 the local database cache is not consistent anymore with the tango database.
-Therefore, spock provides a magic command 'refreshdb' that allows you to reread
+Therefore, itango provides a magic command 'refreshdb' that allows you to reread
 all tango information from the database.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: refreshdb
+    ITango <homer:10000> [1]: refreshdb
     
 Storing your favorite tango objects for later usage
----------------------------------------------------
+-------------------------------------------------------
 
 Since version 7.1.2, :class:`DeviceProxy`, :class:`AttributeProxy` and 
 :class:`Database` became pickable.
 This means that they can be used by the IPython_ 'store' magic command (type
-'store?' on the spock console to get information on how to use this command).
+'store?' on the itango console to get information on how to use this command).
 You can, for example, assign your favorite devices in local python variables and
-then store these for the next time you startup IPython_ with spock profile.
+then store these for the next time you startup IPython_ with itango profile.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: theta = Motor("BL99_M1")  # notice how we used tango alias
+    ITango <homer:10000> [1]: theta = Motor("BL99_M1")  # notice how we used tango alias
     
-    Spock <homer:10000> [2]: store theta
+    ITango <homer:10000> [2]: store theta
     Stored 'theta' (DeviceProxy)
     
-    Spock <homer:10000> [3]: Ctrl+D
+    ITango <homer:10000> [3]: Ctrl+D
     
     (IPython session is closed and started again...)
     
-    Spock <homer:10000> [1]: print theta
+    ITango <homer:10000> [1]: print theta
     DeviceProxy(motor/bl99/1)
     
 Tango color modes
------------------
+--------------------
 
 IPython_ (0.10) provides three color modes: 'Linux', 'NoColor' and 'LightBG'.
-Spock provides in addition 'Tango' (default), 'PurpleTango' (='Tango'),
+ITango provides in addition 'Tango' (default), 'PurpleTango' (='Tango'),
 'BlueTango' and 'GreenTango'.
 
 You can switch between color modes online using the magic command 'colors'.
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: colors BlueTango
+    ITango <homer:10000> [1]: colors BlueTango
     
-    Spock <homer:10000> [2]: colors NoColor
+    ITango <homer:10000> [2]: colors NoColor
 
-Adding spock to your own ipython profile
-----------------------------------------
+Adding itango to your own ipython profile
+--------------------------------------------
 
-Adding spock to the ipython default profile
-###########################################
+Adding itango to the ipython default profile
+##################################################
 
-Let's assume that you find spock so useful that each time you start ipython, you want
-spock features to be loaded by default.
+Let's assume that you find itango so useful that each time you start ipython, you want
+itango features to be loaded by default.
 The way to do this is by editing your default ipython configuration file: 
 $HOME/.ipython/ipy_user_conf.py and add the lines 1 and 7.
 
@@ -374,7 +374,7 @@ And now, every time you start ipython::
 
     ipython
 
-spock features will also be loaded.
+itango features will also be loaded.
 
 .. sourcecode:: ipython
 
@@ -382,13 +382,13 @@ spock features will also be loaded.
     Out[1]: Database(homer, 10000)
 
 
-Adding spock to an existing customized profile
-##############################################
+Adding itango to an existing customized profile
+####################################################
 
 If you have been working with IPython_ before and have already defined a
-customized personal profile, you can extend your profile with spock features 
-without breaking your existing options. The trick is to initialize spock extension
-with a parameter that tells spock to maintain the existing options (like colors,
+customized personal profile, you can extend your profile with itango features 
+without breaking your existing options. The trick is to initialize itango extension
+with a parameter that tells itango to maintain the existing options (like colors,
 command line and initial banner).
 
 So, for example, let's say you have created a profile called nuclear, and therefore
@@ -410,7 +410,7 @@ contents:
         
     main()
 
-In order to have spock features available to this profile you simply need to
+In order to have itango features available to this profile you simply need to
 add two lines of code (lines 3 and 7):
 
 .. sourcecode:: python
@@ -430,13 +430,13 @@ add two lines of code (lines 3 and 7):
         
     main()
 
-This will load the spock features into your profile while preserving your
+This will load the itango features into your profile while preserving your
 profile's console options (like colors, command line and initial banner).
 
-Creating a profile that extends spock profile
-#############################################
+Creating a profile that extends itango profile
+####################################################
 
-It is also possible to create a profile that includes all spock features and at
+It is also possible to create a profile that includes all itango features and at
 the same time adds new ones. Let's suppose that you want to create a customized
 profile called 'orbit' that automaticaly exports devices of class 
 'Libera' for the booster accelerator (assuming you are working on a synchrotron
@@ -503,26 +503,26 @@ Then start your CLI with::
 
 and you will have something like this
 
-.. image:: spock02.png
+.. image:: itango02.png
 
 Advanced event monitoring
 -------------------------
 
-With spock it is possible to monitor change events triggered by any tango
+With itango it is possible to monitor change events triggered by any tango
 attribute which has events enabled.
 
 To start monitoring the change events of an attribute:
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: mon -a BL99_M1/Position
+    ITango <homer:10000> [1]: mon -a BL99_M1/Position
     'BL99_M1/Position' is now being monitored. Type 'mon' to see all events
     
 To list all events that have been intercepted:
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [2]: mon
+    ITango <homer:10000> [2]: mon
       ID           Device    Attribute            Value       Quality             Time
     ---- ---------------- ------------ ---------------- ------------- ----------------
        0     motor/bl99/1        state               ON    ATTR_VALID  17:11:08.026472
@@ -544,7 +544,7 @@ To list all events that have been intercepted:
       16     motor/bl99/1     position            100.0    ATTR_ALARM  17:12:13.738136
       17     motor/bl99/1        state            ALARM    ATTR_VALID  17:12:13.743481
 
-    Spock <homer:10000> [3]: mon -l mot.* state
+    ITango <homer:10000> [3]: mon -l mot.* state
       ID           Device    Attribute            Value       Quality             Time
     ---- ---------------- ------------ ---------------- ------------- ----------------
        0     motor/bl99/1        state               ON    ATTR_VALID  17:11:08.026472
@@ -553,9 +553,9 @@ To list all events that have been intercepted:
 
 To stop monitoring the attribute:
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: mon -d BL99_M1/Position
+    ITango <homer:10000> [1]: mon -d BL99_M1/Position
     Stopped monitoring 'BL99_M1/Position'
 
 .. note::
@@ -567,11 +567,11 @@ To stop monitoring the attribute:
     be available you need two things:
 
         #. Have PyQt4 (>= 4.1) installed
-        #. Start spock with '-q4thread' support: 'ipython -q4thread -p spock'
+        #. Start itango with '-q4thread' support: 'ipython -q4thread -p itango'
 
     When you type '%mon' the following table should appear:
 
-        .. image:: spock04.png
+        .. image:: itango04.png
 
 .. _IPython: http://ipython.scipy.org/
 .. _Tango: http://www.tango-controls.org/
diff --git a/doc/itango/index.rst b/doc/itango/index.rst
new file mode 100644
index 0000000..d62574d
--- /dev/null
+++ b/doc/itango/index.rst
@@ -0,0 +1,37 @@
+.. highlight:: python
+   :linenothreshold: 4
+
+.. _itango:
+
+ITango
+======
+
+ITango is a PyTango CLI based on IPython_. It is designed to be used as an
+IPython profile.
+
+ITango is available since PyTango 7.1.2
+
+You can start ITango by typing on the command line
+
+#. For ipython <= 0.10::
+    
+    $ ipython -p tango
+
+#. For ipython > 0.10::
+
+    $ ipython --profile=tango
+
+and you should get something like this:
+
+.. image:: spock00.png
+
+.. toctree::
+    :maxdepth: 1
+
+    features
+    highlights
+
+--------------------------------------------------------------------------------
+
+.. _IPython: http://ipython.scipy.org/
+.. _Tango: http://www.tango-controls.org/
\ No newline at end of file
diff --git a/doc/spock/spock00.png b/doc/itango/itango00.png
similarity index 100%
rename from doc/spock/spock00.png
rename to doc/itango/itango00.png
diff --git a/doc/spock/spock01.png b/doc/itango/itango01.png
similarity index 100%
rename from doc/spock/spock01.png
rename to doc/itango/itango01.png
diff --git a/doc/spock/spock02.png b/doc/itango/itango02.png
similarity index 100%
rename from doc/spock/spock02.png
rename to doc/itango/itango02.png
diff --git a/doc/spock/spock03.png b/doc/itango/itango03.png
similarity index 100%
rename from doc/spock/spock03.png
rename to doc/itango/itango03.png
diff --git a/doc/spock/spock04.png b/doc/itango/itango04.png
similarity index 100%
rename from doc/spock/spock04.png
rename to doc/itango/itango04.png
diff --git a/doc/quicktour.rst b/doc/quicktour.rst
index ab8c6cf..874be64 100644
--- a/doc/quicktour.rst
+++ b/doc/quicktour.rst
@@ -4,52 +4,58 @@ A quick tour
 ------------
 
 This quick tour will guide you through the first steps on using PyTango.
-This is the new quick tour guide based on the :ref:`spock` console.
+This is the new quick tour guide based on the :ref:`itango` console.
 You can still find the old version of this tour based on a simple python
 console :ref:`here <quick-tour-old>`.
 
 Check PyTango version
 ~~~~~~~~~~~~~~~~~~~~~
 
-Start an ipython spock console with::
+Start an ipython tango console with:
 
-    ipython -p spock
+    #. on IPython <= 0.10:
+    
+        ipython -p tango
+        
+    #. on IPython > 0.10:
+    
+        ipython --profile=tango
 
 and type:
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
 
-        Spock <homer:10000> [1]: PyTango.__version__
+        ITango <homer:10000> [1]: PyTango.__version__
                      Result [1]: '7.1.2'
 
-        Spock <homer:10000> [2]: PyTango.__version_long__
+        ITango <homer:10000> [2]: PyTango.__version_long__
                      Result [2]: '7.1.2dev0'
 
-        Spock <homer:10000> [3]: PyTango.__version_number__
+        ITango <homer:10000> [3]: PyTango.__version_number__
                      Result [3]: 712
 
-        Spock <homer:10000> [4]: PyTango.__version_description__
+        ITango <homer:10000> [4]: PyTango.__version_description__
                      Result [4]: 'This version implements the C++ Tango 7.1 API.'
 
 or alternatively:
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
 
-        Spock <homer:10000> [1]: PyTango.Release.version
+        ITango <homer:10000> [1]: PyTango.Release.version
                      Result [1]: '7.1.2'
 
-        Spock <homer:10000> [2]: PyTango.Release.version_long
+        ITango <homer:10000> [2]: PyTango.Release.version_long
                      Result [2]: '7.1.2dev0'
 
-        Spock <homer:10000> [3]: PyTango.Release.version_number
+        ITango <homer:10000> [3]: PyTango.Release.version_number
                      Result [3]: 712
 
-        Spock <homer:10000> [4]: PyTango.Release.version_description
+        ITango <homer:10000> [4]: PyTango.Release.version_description
                      Result [4]: 'This version implements the C++ Tango 7.1 API.'
 
 .. tip::
 
-    When typing, try pressing <tab>. Since Spock has autocomplete embedded you
+    When typing, try pressing <tab>. Since ITango has autocomplete embedded you
     should get a list of possible completions. Example::
     
         PyTango.Release.<tab>
@@ -61,11 +67,11 @@ Check Tango C++ version
 
 From a client (This is only possible since PyTango 7.0.0)
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
 
-        Spock <homer:10000> [1]: import PyTango.constants
+        ITango <homer:10000> [1]: import PyTango.constants
 
-        Spock <homer:10000> [2]: PyTango.constants.TgLibVers
+        ITango <homer:10000> [2]: PyTango.constants.TgLibVers
                      Result [2]: '7.1.1'
 
 From a server you can alternatively do::
@@ -80,10 +86,10 @@ Test the connection to the Device and get it's current state
 One of the most basic examples is to get a reference to a device and
 determine if it is running or not.
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
         
-        Spock <homer:10000> [1]: # What is a DeviceProxy, really?
-        Spock <homer:10000> [1]: DeviceProxy?
+        ITango <homer:10000> [1]: # What is a DeviceProxy, really?
+        ITango <homer:10000> [1]: DeviceProxy?
         DeviceProxy is the high level Tango object which provides the client with
         an easy-to-use interface to TANGO devices. DeviceProxy provides interfaces
         to all TANGO Device interfaces.The DeviceProxy manages timeouts, stateless
@@ -93,25 +99,26 @@ determine if it is running or not.
         Example :
            dev = PyTango.DeviceProxy("sys/tg_test/1")
            
-        Spock <homer:10000> [2]: tangotest = DeviceProxy("sys/tg_test/1")
+        ITango <homer:10000> [2]: tangotest = DeviceProxy("sys/tg_test/1")
 
-        Spock <homer:10000> [3]: # ping it
-        Spock <homer:10000> [4]: tangotest.ping()
+        ITango <homer:10000> [3]: # ping it
+        ITango <homer:10000> [4]: tangotest.ping()
                      Result [4]: 110
 
-        Spock <homer:10000> [3]: # Lets test the state
-        Spock <homer:10000> [5]: tangotest.state()
+        ITango <homer:10000> [3]: # Lets test the state
+        ITango <homer:10000> [5]: tangotest.state()
                      Result [5]: PyTango._PyTango.DevState.RUNNING
 
-        Spock <homer:10000> [3]: # And now the status
-        Spock <homer:10000> [5]: tangotest.status()
+        ITango <homer:10000> [3]: # And now the status
+        ITango <homer:10000> [5]: tangotest.status()
                      Result [5]: 'The device is in RUNNING state.'
 
 .. note::
-    Did you notice that you didn't write PyTango.DeviceProxy but instead just DeviceProxy?
-    This is because :ref:`spock` automatically exports the :class:`PyTango.DeviceProxy`,
-    :class:`PyTango.AttributeProxy`, :class:`PyTango.Database` and :class:`PyTango.Group`
-    classes to the namespace. If you are writting code outside :ref:`spock` you **MUST**
+    Did you notice that you didn't write PyTango.DeviceProxy but instead just
+    DeviceProxy? This is because :ref:`itango` automatically exports the
+    :class:`PyTango.DeviceProxy`, :class:`PyTango.AttributeProxy`,
+    :class:`PyTango.Database` and :class:`PyTango.Group` classes to the
+    namespace. If you are writting code outside :ref:`itango` you **MUST**
     use the `PyTango` module prefix.
 
 .. tip::
@@ -127,8 +134,8 @@ determine if it is running or not.
         tangotest = TangoTest("<tab>
 
     Now the list of devices should be reduced to the ones that belong to the 
-    'TangoTest' class. Note that TangoTest only works in Spock. If you are 
-    writting code outside :ref:`spock` you **MUST** use 
+    'TangoTest' class. Note that TangoTest only works in ITango. If you are 
+    writting code outside :ref:`itango` you **MUST** use 
     :class:`PyTango.DeviceProxy` instead.
     
 Execute commands with scalar arguments on a Device
@@ -137,22 +144,22 @@ Execute commands with scalar arguments on a Device
 As you can see in the following example, when scalar types are used, PyTango
 automatically manages the data types, and writing scripts is quite easy.
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
     
-        Spock <homer:10000> [1]: tangotest = TangoTest("sys/tg_test/1")
+        ITango <homer:10000> [1]: tangotest = TangoTest("sys/tg_test/1")
 
-        Spock <homer:10000> [2]: # classical way
-        Spock <homer:10000> [2]: r = tangotest.command_inout("DevString", "Hello, world!")
+        ITango <homer:10000> [2]: # classical way
+        ITango <homer:10000> [2]: r = tangotest.command_inout("DevString", "Hello, world!")
 
-        Spock <homer:10000> [3]: print "Result of execution of DevString command =", r
+        ITango <homer:10000> [3]: print "Result of execution of DevString command =", r
         Result of execution of DevString command = Hello, world!
 
-        Spock <homer:10000> [4]: # 'pythonic' way
-        Spock <homer:10000> [5]: tangotest.DevString("Hello, world!")
+        ITango <homer:10000> [4]: # 'pythonic' way
+        ITango <homer:10000> [5]: tangotest.DevString("Hello, world!")
                      Result [5]: 'Hello, world!'
         
-        Spock <homer:10000> [6]: # type is automatically managed by PyTango
-        Spock <homer:10000> [7]: tangotest.DevULong(12456)
+        ITango <homer:10000> [6]: # type is automatically managed by PyTango
+        ITango <homer:10000> [7]: tangotest.DevULong(12456)
                      Result [7]: 12456
 
 Execute commands with more complex types
@@ -161,13 +168,13 @@ Execute commands with more complex types
 In this case you have to use put your arguments data in the correct python
 structures.
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
     
-        Spock <homer:10000> [1]: tangotest = TangoTest("sys/tg_test/1")
+        ITango <homer:10000> [1]: tangotest = TangoTest("sys/tg_test/1")
 
-        Spock <homer:10000> [2]: argin = [1, 2, 3], ["Hello", "World"]
+        ITango <homer:10000> [2]: argin = [1, 2, 3], ["Hello", "World"]
 
-        Spock <homer:10000> [3]: tango_test.DevVarLongArray(argin)
+        ITango <homer:10000> [3]: tango_test.DevVarLongArray(argin)
                      Result [3]: [array([1, 2, 3]), ['Hello', 'World']]
         
 .. note::
@@ -181,10 +188,10 @@ Reading and writing attributes
 
 Basic read/write attribute operations.
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
     
-        Spock <homer:10000> [1]: # Read a scalar attribute
-        Spock <homer:10000> [2]: print tangotest.read_attribute("long_scalar")
+        ITango <homer:10000> [1]: # Read a scalar attribute
+        ITango <homer:10000> [2]: print tangotest.read_attribute("long_scalar")
         DeviceAttribute[
         data_format = PyTango._PyTango.AttrDataFormat.SCALAR
               dim_x = 1
@@ -204,8 +211,8 @@ Basic read/write attribute operations.
         w_dimension = AttributeDimension(dim_x = 1, dim_y = 0)
             w_value = 0]
             
-        Spock <homer:10000> [3]: # Read a spectrum attribute
-        Spock <pc151:10000> [4]: print tangotest.read_attribute("double_spectrum")
+        ITango <homer:10000> [3]: # Read a spectrum attribute
+        ITango <pc151:10000> [4]: print tangotest.read_attribute("double_spectrum")
         DeviceAttribute[
         data_format = PyTango._PyTango.AttrDataFormat.SPECTRUM
               dim_x = 20
@@ -227,33 +234,33 @@ Basic read/write attribute operations.
             w_value = array([  0.,   1.,   2.,   3.,   4.,   5.,   6.,   7.,   8.,   9.,  10.,
                 11.,  12.,  13.,  14.,  15.,  16.,  17.,  18.,  19.])]
 
-        Spock <homer:10000> [5]: # Write a scalar attribute
-        Spock <homer:10000> [6]: scalar_value = 18
-        Spock <homer:10000> [7]: tangotest.write_attribute("long_scalar", scalar_value)
+        ITango <homer:10000> [5]: # Write a scalar attribute
+        ITango <homer:10000> [6]: scalar_value = 18
+        ITango <homer:10000> [7]: tangotest.write_attribute("long_scalar", scalar_value)
 
-        Spock <homer:10000> [8]: # Write a spectrum attribute
-        Spock <homer:10000> [9]: spectrum_value = numpy.random.rand(100)*10
-        Spock <homer:10000> [10]: tangotest.write_attribute("double_spectrum", spectrum_value)
+        ITango <homer:10000> [8]: # Write a spectrum attribute
+        ITango <homer:10000> [9]: spectrum_value = numpy.random.rand(100)*10
+        ITango <homer:10000> [10]: tangotest.write_attribute("double_spectrum", spectrum_value)
         
         
-        Spock <homer:10000> [11]: # Write an image attribute
-        Spock <homer:10000> [12]: image_value = numpy.random.randint(0,10,size=(10,10))
-        Spock <homer:10000> [13]: tangotest.write_attribute("long_image", image_value)
+        ITango <homer:10000> [11]: # Write an image attribute
+        ITango <homer:10000> [12]: image_value = numpy.random.randint(0,10,size=(10,10))
+        ITango <homer:10000> [13]: tangotest.write_attribute("long_image", image_value)
 
 .. tip::
     
     If you are only interested in the attribute's read value you can do insted:
     
-    .. sourcecode:: spock
+    .. sourcecode:: itango
         
-            Spock <homer:10000> [1]: tangotest.long_scalar
+            ITango <homer:10000> [1]: tangotest.long_scalar
                          Result [1]: 239
     
     The same is valid for writting a new value to an attribute:
     
-    .. sourcecode:: spock
+    .. sourcecode:: itango
         
-            Spock <homer:10000> [1]: tangotest.long_scalar = 18
+            ITango <homer:10000> [1]: tangotest.long_scalar = 18
     
 .. note::
 
@@ -279,30 +286,30 @@ Registering devices
 
 Defining devices in the Tango DataBase:
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
     
-        Spock <homer:10000> [1]: # The 3 devices name we want to create
-        Spock <homer:10000> [2]: # Note: these 3 devices will be served by the same DServer
-        Spock <homer:10000> [3]: new_device_name1="px1/tdl/mouse1"
-        Spock <homer:10000> [4]: new_device_name2="px1/tdl/mouse2"
-        Spock <homer:10000> [5]: new_device_name3="px1/tdl/mouse3"
+        ITango <homer:10000> [1]: # The 3 devices name we want to create
+        ITango <homer:10000> [2]: # Note: these 3 devices will be served by the same DServer
+        ITango <homer:10000> [3]: new_device_name1="px1/tdl/mouse1"
+        ITango <homer:10000> [4]: new_device_name2="px1/tdl/mouse2"
+        ITango <homer:10000> [5]: new_device_name3="px1/tdl/mouse3"
 
-        Spock <homer:10000> [6]: # Define the Tango Class served by this DServer
-        Spock <homer:10000> [7]: new_device_info_mouse = PyTango.DbDevInfo()
-        Spock <homer:10000> [8]: new_device_info_mouse._class = "Mouse"
-        Spock <homer:10000> [9]: new_device_info_mouse.server = "ds_Mouse/server_mouse"
+        ITango <homer:10000> [6]: # Define the Tango Class served by this DServer
+        ITango <homer:10000> [7]: new_device_info_mouse = PyTango.DbDevInfo()
+        ITango <homer:10000> [8]: new_device_info_mouse._class = "Mouse"
+        ITango <homer:10000> [9]: new_device_info_mouse.server = "ds_Mouse/server_mouse"
 
-        Spock <homer:10000> [10]: # add the first device
-        Spock <homer:10000> [11]: new_device_info_mouse.name = new_device_name1
-        Spock <homer:10000> [12]: db.add_device(new_device_info_mouse)
+        ITango <homer:10000> [10]: # add the first device
+        ITango <homer:10000> [11]: new_device_info_mouse.name = new_device_name1
+        ITango <homer:10000> [12]: db.add_device(new_device_info_mouse)
 
-        Spock <homer:10000> [13]: # add the next device
-        Spock <homer:10000> [14]: new_device_info_mouse.name = new_device_name2
-        Spock <homer:10000> [15]: db.add_device(new_device_info_mouse)
+        ITango <homer:10000> [13]: # add the next device
+        ITango <homer:10000> [14]: new_device_info_mouse.name = new_device_name2
+        ITango <homer:10000> [15]: db.add_device(new_device_info_mouse)
 
-        Spock <homer:10000> [16]: # add the third device
-        Spock <homer:10000> [17]: new_device_info_mouse.name = new_device_name3
-        Spock <homer:10000> [18]: db.add_device(new_device_info_mouse)
+        ITango <homer:10000> [16]: # add the third device
+        ITango <homer:10000> [17]: new_device_info_mouse.name = new_device_name3
+        ITango <homer:10000> [18]: db.add_device(new_device_info_mouse)
 
 Setting up Device properties
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -312,13 +319,13 @@ The following python script example (containing some functions and instructions
 manipulating a Galil motor axis device server) gives an idea of how the Tango
 API should be accessed from Python.
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
     
-        Spock <homer:10000> [1]: # connecting to the motor axis device
-        Spock <homer:10000> [2]: axis1 = DeviceProxy ("microxas/motorisation/galilbox")
+        ITango <homer:10000> [1]: # connecting to the motor axis device
+        ITango <homer:10000> [2]: axis1 = DeviceProxy ("microxas/motorisation/galilbox")
 
-        Spock <homer:10000> [3]: # Getting Device Properties
-        Spock <homer:10000> [4]: property_names = ["AxisBoxAttachement",
+        ITango <homer:10000> [3]: # Getting Device Properties
+        ITango <homer:10000> [4]: property_names = ["AxisBoxAttachement",
                            ....:                   "AxisEncoderType",
                            ....:                   "AxisNumber",
                            ....:                   "CurrentAcceleration",
@@ -338,36 +345,36 @@ API should be accessed from Python.
                            ....:                   "UserEncoderRatio",
                            ....:                   "UserOffset"]
         
-        Spock <homer:10000> [5]: axis_properties = axis1.get_property(property_names)
-        Spock <homer:10000> [6]: for prop in axis_properties.keys():
+        ITango <homer:10000> [5]: axis_properties = axis1.get_property(property_names)
+        ITango <homer:10000> [6]: for prop in axis_properties.keys():
                            ....:     print "%s: %s" % (prop, axis_properties[prop][0])
 
-        Spock <homer:10000> [7]: # Changing Properties
-        Spock <homer:10000> [8]: axis_properties["AxisBoxAttachement"] = ["microxas/motorisation/galilbox"]
-        Spock <homer:10000> [9]: axis_properties["AxisEncoderType"] = ["1"]
-        Spock <homer:10000> [10]: axis_properties["AxisNumber"] = ["6"]
-        Spock <homer:10000> [11]: axis1.put_property(axis_properties)
+        ITango <homer:10000> [7]: # Changing Properties
+        ITango <homer:10000> [8]: axis_properties["AxisBoxAttachement"] = ["microxas/motorisation/galilbox"]
+        ITango <homer:10000> [9]: axis_properties["AxisEncoderType"] = ["1"]
+        ITango <homer:10000> [10]: axis_properties["AxisNumber"] = ["6"]
+        ITango <homer:10000> [11]: axis1.put_property(axis_properties)
 
-        Spock <homer:10000> [12]: # Reading attributes
-        Spock <homer:10000> [13]: att_list = axis.get_attribute_list()
-        Spock <homer:10000> [14]: for att in att_list:
+        ITango <homer:10000> [12]: # Reading attributes
+        ITango <homer:10000> [13]: att_list = axis.get_attribute_list()
+        ITango <homer:10000> [14]: for att in att_list:
                             ....:     att_val = axis.read_attribute(att)
                             ....:     print "%s: %s" % (att.name, att_val.value)
 
-        Spock <homer:10000> [15]: # Changing some attribute values
-        Spock <homer:10000> [16]: axis1.write_attribute("AxisBackslash", 0.5)
-        Spock <homer:10000> [17]: axis1.write_attribute("AxisDirection", 1.0)
-        Spock <homer:10000> [18]: axis1.write_attribute("AxisVelocity", 1000.0)
-        Spock <homer:10000> [19]: axis1.write_attribute("AxisOvershoot", 500.0)
+        ITango <homer:10000> [15]: # Changing some attribute values
+        ITango <homer:10000> [16]: axis1.write_attribute("AxisBackslash", 0.5)
+        ITango <homer:10000> [17]: axis1.write_attribute("AxisDirection", 1.0)
+        ITango <homer:10000> [18]: axis1.write_attribute("AxisVelocity", 1000.0)
+        ITango <homer:10000> [19]: axis1.write_attribute("AxisOvershoot", 500.0)
 
-        Spock <homer:10000> [20]: # Testing some device commands
-        Spock <homer:10000> [21]: pos1=axis1.read_attribute("AxisCurrentPosition")
-        Spock <homer:10000> [22]: axis1.command_inout("AxisBackward")
-        Spock <homer:10000> [23]: while pos1.value > 1000.0:
+        ITango <homer:10000> [20]: # Testing some device commands
+        ITango <homer:10000> [21]: pos1=axis1.read_attribute("AxisCurrentPosition")
+        ITango <homer:10000> [22]: axis1.command_inout("AxisBackward")
+        ITango <homer:10000> [23]: while pos1.value > 1000.0:
                             ....:     pos1 = axis1.read_attribute("AxisCurrentPosition")
                             ....:     print "position axis 1 = ", pos1.value
                             
-        Spock <homer:10000> [24]: axis1.command_inout("AxisStop")
+        ITango <homer:10000> [24]: axis1.command_inout("AxisStop")
 
 A quick tour of Tango device server binding through an example
 --------------------------------------------------------------
diff --git a/doc/quicktour_old.rst b/doc/quicktour_old.rst
index fc8633e..5efcceb 100644
--- a/doc/quicktour_old.rst
+++ b/doc/quicktour_old.rst
@@ -5,7 +5,7 @@ A quick tour (original)
 
 This quick tour will guide you through the first steps on using PyTango.
 This is the original quick tour guide that uses a simple Python console.
-There is a new version of this document which uses :ref:`spock` console in its
+There is a new version of this document which uses :ref:`itango` console in its
 examples. You can find this new version :ref:`here <quick-tour>`.
 
 Check PyTango version
diff --git a/doc/spock/index.rst b/doc/spock/index.rst
deleted file mode 100644
index 90cbb29..0000000
--- a/doc/spock/index.rst
+++ /dev/null
@@ -1,46 +0,0 @@
-.. highlight:: python
-   :linenothreshold: 4
-
-.. _spock:
-
-Spock
-=====
-
-Spock is a PyTango CLI based on IPython_. It is designed to be used as an
-IPython extension or a profile [#ExtProfile]_.
-
-Spock is available since PyTango 7.1.2
-
-.. note::
-    'spock' used to be the name given to the CLI dedicated to Sardana. Now spock
-    became a generic Tango CLI and the connection to Sardana is provided as an
-    extension to spock. This sardana extension is NOT supplied by PyTango but is 
-    available from the Sardana package.
-
-You can start spock by typing on the command line::
-    
-    $ ipython -p spock
-
-and you should get something like this:
-
-.. image:: spock00.png
-
-.. toctree::
-    :maxdepth: 1
-
-    features
-    highlights
-
---------------------------------------------------------------------------------
-
-.. [#ExtProfile] The difference between extension and profile is that an
-   extension is installed in the IPython installation extension directory and
-   therefore becomes available to all users of the machine automatically.
-   As a profile, it must be installed in each user's ipython configuration directory
-   (in linux, is usualy $HOME/.ipython).
-   Note that the spock profile is a very short (3 lines of code) python file.
-   See PyTango :ref:`build-install` for more information on how to install spock
-   as an extension or a profile.
-
-.. _IPython: http://ipython.scipy.org/
-.. _Tango: http://www.tango-controls.org/
\ No newline at end of file
diff --git a/doc/start.rst b/doc/start.rst
index 0bba0e2..106d317 100644
--- a/doc/start.rst
+++ b/doc/start.rst
@@ -58,7 +58,7 @@ The current PyTango version has four major dependencies:
   
 plus two optional dependencies (activated by default) on:
 
-- IPyhon (>=0.10) (http://ipython.scipy.org/) (necessary for :ref:`spock`)
+- IPyhon (>=0.10) (http://ipython.scipy.org/) (necessary for :ref:`itango`)
 - numpy (>= 1.1.0) (http://numpy.scipy.org/)
 
 .. note::
@@ -248,14 +248,14 @@ Finally::
     sudo python setup.py install
     
 This will install PyTango in the system python installation directory and, since
-version 7.1.2, it will also install :ref:`spock` as an IPython_ extension.
+version 7.1.2, it will also install :ref:`itango` as an IPython_ extension.
     
 Or if you whish to install in a different directory::
     
     python setup.py build
     python setup.py install --prefix=/home/homer/local --ipython-local
 
-(This will try to install :ref:`spock` as an IPython profile to the local
+(This will try to install :ref`itango` as an IPython profile to the local
 user, since probably there is no permission to write into the IPython_ extension
 directory)
 
@@ -271,26 +271,26 @@ test
 ####
 
 If you have IPython_ installed, the best way to test your PyTango installation
-is by starting the new PyTango CLI called :ref:`spock` by typing on the command
-line
+is by starting the new PyTango CLI called :ref`itango` by typing on the command
+line:
 
-IPython <= 0.10::
+    #. IPython <= 0.10::
 
-    $ ipython -p spock
+        $ ipython -p tango
 
-IPython > 0.10::
+    #.IPython > 0.10::
 
-    $ ipython --profile spock
+        $ ipython --profile=tango
 
 
-then, in spock type:
+then, in ITango type:
 
-.. sourcecode:: spock
+.. sourcecode:: itango
 
-    Spock <homer:10000> [1]: PyTango.Release.version
-                 Result [1]: '7.1.2'
+    ITango <homer:10000> [1]: PyTango.Release.version
+                  Result [1]: '7.1.2'
 
-(if you are wondering, :ref:`spock` automaticaly does ``import PyTango`` for you!)
+(if you are wondering, :ref`itango` automaticaly does ``import PyTango`` for you!)
 
 If you don't have IPython_ installed, to test the installation start a python console
 and type:

diff --git a/doc/sphinxext/spock_console_highlighting.py b/doc/sphinxext/tango_console_highlighting.py
similarity index 87%
rename from doc/sphinxext/spock_console_highlighting.py
rename to doc/sphinxext/tango_console_highlighting.py
index 94ef6f0..ffff5b9 100644
--- a/doc/sphinxext/spock_console_highlighting.py
+++ b/doc/sphinxext/tango_console_highlighting.py
@@ -21,7 +21,7 @@
 ##
 ################################################################################
 
 """reST directive for syntax-highlighting spock interactive sessions.
 """
 
 #-----------------------------------------------------------------------------
@@ -46,38 +46,38 @@ line_re = re.compile('.*?\n')
 
 DftStyle = pygments.styles.get_style_by_name("default")
 
-class SpockStyle(DftStyle):
+class TangoStyle(DftStyle):
     
     styles = copy.copy(DftStyle.styles)
     styles[Generic.Prompt] = 'bold #800080'
 
-class SpockConsoleLexer(Lexer):
+class TangoConsoleLexer(Lexer):
     """
     For spock console output or doctests, such as:
 
-    .. sourcecode:: spock
+    .. sourcecode:: itango
 
-      Spock <homer:10000> [1]: a = 'foo'
+      ITango <homer:10000> [1]: a = 'foo'
 
-      Spock <homer:10000> [2]: a
+      ITango <homer:10000> [2]: a
                    Result [2]: 'foo'
 
-      Spock <homer:10000> [3]: print a
+      ITango <homer:10000> [3]: print a
       foo
 
-      Spock <homer:10000> [4]: 1 / 0
+      ITango <homer:10000> [4]: 1 / 0
 
     Notes:
 
       - Tracebacks are not currently supported.
 
-      - It assumes the default spock prompts, not customized ones.
+      - It assumes the default itango prompts, not customized ones.
     """
     
-    name = 'Spock console session'
-    aliases = ['spock']
-    mimetypes = ['text/x-spock-console']
-    input_prompt = re.compile("(Spock \<\w+:\d+\> \[(?P<N>[0-9]+)\]: )|(   \.\.\.+:)")
+    name = 'ITango console session'
+    aliases = ['itango']
+    mimetypes = ['text/x-itango-console']
+    input_prompt = re.compile("(ITango \<\w+:\d+\> \[(?P<N>[0-9]+)\]: )|(   \.\.\.+:)")
     output_prompt = re.compile("(\s*Result \[(?P<N>[0-9]+)\]: )|(   \.\.\.+:)")
     continue_prompt = re.compile("   \.\.\.+:")
     tb_start = re.compile("\-+")
@@ -136,4 +136,4 @@ def setup(app):
 
 #-----------------------------------------------------------------------------
 # Register the extension as a valid pygments lexer
-highlighting.lexers['spock'] = SpockConsoleLexer()
\ No newline at end of file
+highlighting.lexers['itango'] = TangoConsoleLexer()
\ No newline at end of file
@@ -21,7 +21,7 @@
 ################################################################################
 
-"""reST directive for syntax-highlighting spock interactive sessions.
+"""reST directive for syntax-highlighting itango interactive sessions.
 """
 
@@ -46,38 +46,38 @@ line_re = re.compile('.*?\n')
     """
-    For spock console output or doctests, such as:
+    For itango console output or doctests, such as:
 
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/debian-science/packages/pytango.git



More information about the debian-science-commits mailing list